==> vkbottle_types-5.131.146.dev0-py3-none-any.whl: vkbottle_types/codegen/methods/storage.py <==
import typing

from typing_extensions import Literal
from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.storage import *
from vkbottle_types.responses.base import OkResponse


class StorageCategory(BaseCategory):
    async def get(
        self,
        key: typing.Optional[str] = None,
        keys: typing.Optional[typing.List[str]] = None,
        user_id: typing.Optional[int] = None,
        **kwargs,
    ) -> StorageGetResponseModel:
        """storage.get method


        :param key:
        :param keys:
        :param user_id:
        """
        params = self.get_set_params(locals())
        response = await self.api.request("account.ban", params)

        model = StorageGetResponse

        return model(**response).response

    async def get_keys(
        self,
        user_id: typing.Optional[int] = None,
        offset: typing.Optional[int] = 0,
        count: typing.Optional[int] = 100,
        **kwargs,
    ) -> StorageGetKeysResponseModel:
        """storage.getKeys method


        :param user_id: user id, whose variables names are returned if they were requested with a server method.
        :param offset:
        :param count: amount of variable names the info needs to be collected from.
        """
        params = self.get_set_params(locals())
        response = await self.api.request("account.ban", params)

        model = StorageGetKeysResponse

        return model(**response).response

    async def set(
        self,
        key: str,
        value: typing.Optional[str] = None,
        user_id: typing.Optional[int] = None,
        **kwargs,
    ) -> BaseOkResponseModel:
        """storage.set method


        :param key:
        :param value:
        :param user_id:
        """
        params = self.get_set_params(locals())
        response = await self.api.request("account.ban", params)

        model = BaseOkResponse

        return model(**response).response


__all__ = ("StorageCategory",)

==> vkbottle_types-5.131.146.15-py3-none-any.whl: vkbottle_types/codegen/methods/storage.py <==
import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.base import OkResponse
from vkbottle_types.responses.storage import GetKeysResponse, GetResponse, StorageValue


class StorageCategory(BaseCategory):
    async def get(
        self,
        key: typing.Optional[str] = None,
        keys: typing.Optional[typing.List[str]] = None,
        user_id: typing.Optional[int] = None,
        **kwargs
    ) -> typing.List[StorageValue]:
        """Returns a value of variable with the name set by key parameter.

        :param key:
        :param keys:
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("storage.get", params)
        model = GetResponse
        return model(**response).response

    async def get_keys(
        self,
        user_id: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        **kwargs
    ) -> typing.List[str]:
        """Returns the names of all variables.

        :param user_id: user id, whose variables names are returned if they were requested with a server method.
        :param offset:
        :param count: amount of variable names the info needs to be collected from.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("storage.getKeys", params)
        model = GetKeysResponse
        return model(**response).response

    async def set(
        self,
        key: str,
        value: typing.Optional[str] = None,
        user_id: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Saves a value of variable with the name set by 'key' parameter.

        :param key:
        :param value:
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("storage.set", params)
        model = OkResponse
        return model(**response).response


__all__ = ("StorageCategory",)
